package
Version:
v0.0.0-...-382867a
Opens a new window with list of versions in this module.
Published: Apr 25, 2021
License: GPL-3.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 9
Opens a new window with list of known importers.
Documentation
¶
HandlerBool if handlel return true
func HandlerExit(err error)
HandlerExit Handler & Exit with code 1
Source Files
¶
Click to show internal directories.
Click to hide internal directories.